gchecky.model.discount_result_t

Package gchecky :: Module model :: Class discount_result_t |
[hide private]
[frames] | no frames]

# Class discount_result_t

source code

    object --+
             |
     gxml.Node --+
                 |
                discount_result_t

Nested Classes | [hide private]
Inherited from `gxml.Node`: `__metaclass__`

Instance Methods | [hide private]
Inherited from `gxml.Node`: `__eq__`, `__init__`, `__neq__`, `read`, `write` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Methods | [hide private]
Inherited from `gxml.Node`: `fields`, `set_fields`

Static Methods | [hide private]
Inherited from `gxml.Node`: `__new__`

Class Variables | [hide private]
| valid = `gxml.Boolean('valid')`
| calculated_amount = `Node:PATH(calculated-amount):REQ:{ price_t }`
| code = `String:PATH(code):REQ:EMPTY`
| message = `String:PATH(message):REQ:EMPTY`
| _fields = ``{``'``calculated_amount``'``:` Node:PATH(calculated-amount):R`...`` list of meta-Fields of this class.

Properties | [hide private]
Inherited from `object`: `__class__`

Class Variable Details | [hide private]

  ### _fields list of meta-Fields of this class. Value:
      {'calculated_amount': Node:PATH(calculated-amount):REQ:{ price_t },
       'code': String:PATH(code):REQ:EMPTY,
       'message': String:PATH(message):REQ:EMPTY,
       'valid': ??}